package Bundle::IkiWiki::Extras;

$VERSION = '0.01';

1;

__END__

=head1 NAME

Bundle::IkiWiki - modules used by ikiwiki plugins

=head1 SYNOPSIS

perl -MCPAN -e 'install Bundle::IkiWiki::Extras'

=head1 CONTENTS

Authen::Passphrase
Search::Xapian
RPC::XML
File::MimeInfo
Locale::gettext
Net::OpenID::Consumer
LWPx::ParanoidAgent
Crypt::SSLeay
Text::CSV
Text::Typography
Text::Textile
Text::WikiFormat
XML::Feed
Net::Amazon::S3
Text::WikiCreole
Term::ReadLine::Gnu
HTML::Tree
Sort::Naturally

=head1 AUTHOR

Joey Hess <joey@ikiwiki.info>
